{% extends base_template|default:"django_fido/base.html" %}
{% load i18n %}

{% block content_title %}
    <h1>{% trans "Registration done" %}</h1>
{% endblock %}

{% block content %}
    <p>{% trans "Registration done" %}</p>
{% endblock %}
