# Generated by Django 2.2.17 on 2020-12-08 17:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_fido', '0015_unique_metadata_url'),
    ]

    operations = [
        migrations.AlterField(
            model_name='authenticator',
            name='counter',
            field=models.BigIntegerField(default=0),
        ),
    ]
