{% load i18n %}<!DOCTYPE html>
{% get_current_language as LANGUAGE_CODE %}
<html lang="{{ LANGUAGE_CODE }}">
    <head>
        <title>{% block title %}Django FIDO{% endblock %}</title>
        {% block extrastyle %}{% endblock %}
        <script type="text/javascript" src="{% url 'django_fido:javascript_catalog' %}"></script>
        {% block extrahead %}{% endblock %}
    </head>

    <body>
        <div id="container">
            {% block messages %}
                {% if messages %}
                    <ul class="messagelist">
                        {% for message in messages %}
                            <li{% if message.tags %} class="{{ message.tags }}"{% endif %}>{{ message|capfirst }}</li>
                        {% endfor %}
                    </ul>
                {% endif %}
            {% endblock %}

            <div id="content">
                {% block content_title %}
                    {% if view.title %}<h1>{{ view.title }}</h1>{% endif %}
                {% endblock %}
                {% block content %}{% endblock %}
            </div>
        </div>
    </body>
</html>
