# Generated by Django 3.1.12 on 2021-06-28 15:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_fido', '0016_bigint_store'),
    ]

    operations = [
        migrations.AlterField(
            model_name='authenticatormetadata',
            name='url',
            field=models.URLField(blank=True, null=True, unique=True),
        ),
    ]
